@@ -3,7 +3,12 @@ import typing
 import pandas as pd
 import pydantic
 
-from retrack.nodes.base import BaseNode, InputConnectionModel, OutputConnectionModel
+from retrack.nodes.base import (
+    BaseNode,
+    InputConnectionModel,
+    NodeKind,
+    OutputConnectionModel,
+)
 
 ################################################
 # If Inputs and Outputs
@@ -28,6 +33,9 @@ class If(BaseNode):
     inputs: IfInputsModel
     outputs: IfOutputsModel
 
+    def kind(self) -> NodeKind:
+        return NodeKind.FILTER
+
     def run(self, input_bool: pd.Series) -> typing.Dict[str, pd.Series]:
         return {
             f"output_then_filter": input_bool,
